package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.person</code>
 * (previously <code>p2j_test.person</code>).
 * <p>
 * Test table with variety of indexes
 */
@LegacyTable(name = "person")
@LegacyIndexes(
{
   @LegacyIndex(name = "site-emp", converted = "person_site_emp",  primary = true),
   @LegacyIndex(name = "comments", converted = "person_comments"),
   @LegacyIndex(name = "emp-ssn", converted = "person_emp_ssn"),
   @LegacyIndex(name = "exten", converted = "person_exten"),
   @LegacyIndex(name = "hire-date", converted = "person_hire_date"),
   @LegacyIndex(name = "name", converted = "person_name"),
   @LegacyIndex(name = "pay-type", converted = "person_pay_type"),
   @LegacyIndex(name = "phone", converted = "person_phone"),
   @LegacyIndex(name = "term-date", converted = "person_term_date")
})
public class PersonImpl
implements Serializable,
           Persistable,
           Person
{
   /** Surrogate primary key */
   private Long id = null;

   /** Site ID */
   @LegacyField( fieldId = 1 , name = "site-id" , format = "99" , initial = "0" , columnLabel = "Site ID" , label = "Site ID" , mandatory = true)
   private final integer siteId;

   /** Data member */
   @LegacyField( fieldId = 2 , name = "emp-num" , format = "9999999" , initial = "0" , columnLabel = "Emp Num Column" , mandatory = true)
   private final integer empNum;

   /** First */
   @LegacyField( fieldId = 3 , name = "first-name" , format = "x(12)" , columnLabel = "First" , label = "First")
   private final character firstName;

   /** Last */
   @LegacyField( fieldId = 4 , name = "last-name" , format = "x(15)" , columnLabel = "Last" , label = "Last")
   private final character lastName;

   /** MI */
   @LegacyField( fieldId = 5 , name = "middle-init" , format = "X" , columnLabel = "MI" , label = "MI")
   private final character middleInit;

   /** SSN */
   @LegacyField( fieldId = 6 , name = "ssn" , format = "x(9)" , initial = "?" , columnLabel = "SSN" , label = "SSN" , mandatory = true)
   private final character ssn;

   /** Pay Type */
   @LegacyField( fieldId = 7 , name = "pay-type" , format = "X" , columnLabel = "Pay Type" , label = "Pay Type")
   private final character payType;

   /** Hired */
   @LegacyField( fieldId = 8 , name = "hire-date" , format = "99/99/9999" , initial = "?" , columnLabel = "Hired" , label = "Hired")
   private final date hireDate;

   /** Terminated */
   @LegacyField( fieldId = 9 , name = "term-date" , format = "99/99/9999" , initial = "?" , columnLabel = "Terminated" , label = "Terminated")
   private final date termDate;

   /** Termination Notice TS */
   @LegacyField( fieldId = 10 , name = "term-notice" , format = "99/99/9999 HH:MM:SS.sss" , initial = "?" , columnLabel = "Termination Notice TS" , label = "Termination Notice TS")
   private final datetime termNotice;

   /** Termination Notice TS-Ext */
   @LegacyField( fieldId = 11 , name = "term-notice-ext" , format = "99/99/9999 HH:MM:SS.sss+HH:MM" , initial = "?" , columnLabel = "Termination Notice TS-Ext" , label = "Termination Notice TS-Ext")
   private final datetimetz termNoticeExt;

   /** Data member */
   @LegacyField( fieldId = 12 , name = "comments" , format = "x(60)")
   private final character comments;

   /** Area Code */
   @LegacyField( fieldId = 13 , name = "area-code" , format = "x(3)" , columnLabel = "Area Code" , label = "Area Code")
   private final character areaCode;

   /** Phone */
   @LegacyField( fieldId = 14 , name = "phone-number" , format = "x(7)" , columnLabel = "Phone" , label = "Phone")
   private final character phoneNumber;

   /** Ext */
   @LegacyField( fieldId = 15 , name = "extension" , format = "x(4)" , columnLabel = "Ext" , label = "Ext")
   private final character extension;

   /** label of schedule2 text */
   @LegacyField( fieldId = 16 , name = "schedule" , label = "label of schedule2 text" , index = 1 , original = "schedule")
   private final character schedule2;

   /** description of schedule1 text */
   @LegacyField( fieldId = 17 , name = "schedule" , label = "" , index = 2 , original = "schedule")
   private final character schedule1;

   /** label of scheduleThird text; description of scheduleThird text */
   @LegacyField( fieldId = 18 , name = "schedule" , label = "label of scheduleThird text" , index = 3 , original = "schedule")
   private final character scheduleThird;

   /** Data member */
   @LegacyField( fieldId = 19 , name = "schedule" , label = "" , index = 4 , original = "schedule")
   private final character scheduleFourth;

   /** Data member */
   @LegacyField( fieldId = 20 , name = "schedule" , format = "x(64)" , label = "" , index = 5 , original = "schedule")
   private final character scheduleFifth;

   /** Hours */
   @LegacyField( fieldId = 21 , name = "hours" , initial = "0" , label = "Hours" , index = 1 , original = "hours")
   private final integer hours1;

   /** Hours */
   @LegacyField( fieldId = 22 , name = "hours" , initial = "0" , label = "Hours" , index = 2 , original = "hours")
   private final integer hours2;

   /** Hours */
   @LegacyField( fieldId = 23 , name = "hours" , initial = "0" , label = "Hours" , index = 3 , original = "hours")
   private final integer hours3;

   /** Hours */
   @LegacyField( fieldId = 24 , name = "hours" , initial = "0" , label = "Hours" , index = 4 , original = "hours")
   private final integer hours4;

   /** Hours */
   @LegacyField( fieldId = 25 , name = "hours" , format = "99" , initial = "0" , label = "Hours" , index = 5 , original = "hours")
   private final integer hours5;

   /**
    * Default constructor.
    */
   public PersonImpl()
   {
      siteId = new integer(0);
      empNum = new integer(0);
      firstName = new character("");
      lastName = new character("");
      middleInit = new character("");
      ssn = new character();
      payType = new character("");
      hireDate = new date();
      termDate = new date();
      termNotice = new datetime();
      termNoticeExt = new datetimetz();
      comments = new character("");
      areaCode = new character("");
      phoneNumber = new character("");
      extension = new character("");
      schedule2 = new character("");
      schedule1 = new character("");
      scheduleThird = new character("");
      scheduleFourth = new character("");
      scheduleFifth = new character("");
      hours1 = new integer(0);
      hours2 = new integer(0);
      hours3 = new integer(0);
      hours4 = new integer(0);
      hours5 = new integer(0);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new PersonImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      PersonImpl from = (PersonImpl) old;
      setId(from.getId());
      setSiteId(from.getSiteId());
      setEmpNum(from.getEmpNum());
      setFirstName(from.getFirstName());
      setLastName(from.getLastName());
      setMiddleInit(from.getMiddleInit());
      setSsn(from.getSsn());
      setPayType(from.getPayType());
      setHireDate(from.getHireDate());
      setTermDate(from.getTermDate());
      setTermNotice(from.getTermNotice());
      setTermNoticeExt(from.getTermNoticeExt());
      setComments(from.getComments());
      setAreaCode(from.getAreaCode());
      setPhoneNumber(from.getPhoneNumber());
      setExtension(from.getExtension());
      setSchedule2(from.getSchedule2());
      setSchedule1(from.getSchedule1());
      setScheduleThird(from.getScheduleThird());
      setScheduleFourth(from.getScheduleFourth());
      setScheduleFifth(from.getScheduleFifth());
      setHours1(from.getHours1());
      setHours2(from.getHours2());
      setHours3(from.getHours3());
      setHours4(from.getHours4());
      setHours5(from.getHours5());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Site ID
    * 
    * @return  Site ID
    */
   public integer getSiteId()
   {
      return (new integer(siteId));
   }

   /**
    * Setter: Site ID
    * 
    * @param   siteId
    *          Site ID
    */
   public void setSiteId(NumberType siteId)
   {
      this.siteId.assign(siteId, true);
   }

   /**
    * Getter: empNum
    * 
    * @return  empNum
    */
   public integer getEmpNum()
   {
      return (new integer(empNum));
   }

   /**
    * Setter: empNum
    * 
    * @param   empNum
    *          empNum
    */
   public void setEmpNum(NumberType empNum)
   {
      this.empNum.assign(empNum, true);
   }

   /**
    * Getter: First
    * 
    * @return  First
    */
   public character getFirstName()
   {
      return (new character(firstName));
   }

   /**
    * Setter: First
    * 
    * @param   firstName
    *          First
    */
   public void setFirstName(Text firstName)
   {
      this.firstName.assign(firstName, true);
   }

   /**
    * Getter: Last
    * 
    * @return  Last
    */
   public character getLastName()
   {
      return (new character(lastName));
   }

   /**
    * Setter: Last
    * 
    * @param   lastName
    *          Last
    */
   public void setLastName(Text lastName)
   {
      this.lastName.assign(lastName, true);
   }

   /**
    * Getter: MI
    * 
    * @return  MI
    */
   public character getMiddleInit()
   {
      return (new character(middleInit));
   }

   /**
    * Setter: MI
    * 
    * @param   middleInit
    *          MI
    */
   public void setMiddleInit(Text middleInit)
   {
      this.middleInit.assign(middleInit, true);
   }

   /**
    * Getter: SSN
    * 
    * @return  SSN
    */
   public character getSsn()
   {
      return (new character(ssn));
   }

   /**
    * Setter: SSN
    * 
    * @param   ssn
    *          SSN
    */
   public void setSsn(Text ssn)
   {
      this.ssn.assign(ssn, true);
   }

   /**
    * Getter: Pay Type
    * 
    * @return  Pay Type
    */
   public character getPayType()
   {
      return (new character(payType));
   }

   /**
    * Setter: Pay Type
    * 
    * @param   payType
    *          Pay Type
    */
   public void setPayType(Text payType)
   {
      this.payType.assign(payType, true);
   }

   /**
    * Getter: Hired
    * 
    * @return  Hired
    */
   public date getHireDate()
   {
      return (new date(hireDate));
   }

   /**
    * Setter: Hired
    * 
    * @param   hireDate
    *          Hired
    */
   public void setHireDate(date hireDate)
   {
      this.hireDate.assign(hireDate, true);
   }

   /**
    * Getter: Terminated
    * 
    * @return  Terminated
    */
   public date getTermDate()
   {
      return (new date(termDate));
   }

   /**
    * Setter: Terminated
    * 
    * @param   termDate
    *          Terminated
    */
   public void setTermDate(date termDate)
   {
      this.termDate.assign(termDate, true);
   }

   /**
    * Getter: Termination Notice TS
    * 
    * @return  Termination Notice TS
    */
   public datetime getTermNotice()
   {
      return (new datetime(termNotice));
   }

   /**
    * Setter: Termination Notice TS
    * 
    * @param   termNotice
    *          Termination Notice TS
    */
   public void setTermNotice(date termNotice)
   {
      this.termNotice.assign(termNotice, true);
   }

   /**
    * Getter: Termination Notice TS-Ext
    * 
    * @return  Termination Notice TS-Ext
    */
   public datetimetz getTermNoticeExt()
   {
      return (new datetimetz(termNoticeExt));
   }

   /**
    * Setter: Termination Notice TS-Ext
    * 
    * @param   termNoticeExt
    *          Termination Notice TS-Ext
    */
   public void setTermNoticeExt(date termNoticeExt)
   {
      this.termNoticeExt.assign(termNoticeExt, true);
   }

   /**
    * Getter: comments
    * 
    * @return  comments
    */
   public character getComments()
   {
      return (new character(comments));
   }

   /**
    * Setter: comments
    * 
    * @param   comments
    *          comments
    */
   public void setComments(Text comments)
   {
      this.comments.assign(comments, true);
   }

   /**
    * Getter: Area Code
    * 
    * @return  Area Code
    */
   public character getAreaCode()
   {
      return (new character(areaCode));
   }

   /**
    * Setter: Area Code
    * 
    * @param   areaCode
    *          Area Code
    */
   public void setAreaCode(Text areaCode)
   {
      this.areaCode.assign(areaCode, true);
   }

   /**
    * Getter: Phone
    * 
    * @return  Phone
    */
   public character getPhoneNumber()
   {
      return (new character(phoneNumber));
   }

   /**
    * Setter: Phone
    * 
    * @param   phoneNumber
    *          Phone
    */
   public void setPhoneNumber(Text phoneNumber)
   {
      this.phoneNumber.assign(phoneNumber, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension()
   {
      return (new character(extension));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension
    *          Ext
    */
   public void setExtension(Text extension)
   {
      this.extension.assign(extension, true);
   }

   /**
    * Getter: label of schedule2 text
    * 
    * @return  label of schedule2 text
    */
   public character getSchedule2()
   {
      return (new character(schedule2));
   }

   /**
    * Setter: label of schedule2 text
    * 
    * @param   schedule2
    *          label of schedule2 text
    */
   public void setSchedule2(Text schedule2)
   {
      this.schedule2.assign(schedule2, true);
   }

   /**
    * Getter: description of schedule1 text
    * 
    * @return  schedule1
    */
   public character getSchedule1()
   {
      return (new character(schedule1));
   }

   /**
    * Setter: description of schedule1 text
    * 
    * @param   schedule1
    *          schedule1
    */
   public void setSchedule1(Text schedule1)
   {
      this.schedule1.assign(schedule1, true);
   }

   /**
    * Getter: description of scheduleThird text
    * 
    * @return  label of scheduleThird text
    */
   public character getScheduleThird()
   {
      return (new character(scheduleThird));
   }

   /**
    * Setter: description of scheduleThird text
    * 
    * @param   scheduleThird
    *          label of scheduleThird text
    */
   public void setScheduleThird(Text scheduleThird)
   {
      this.scheduleThird.assign(scheduleThird, true);
   }

   /**
    * Getter: scheduleFourth
    * 
    * @return  scheduleFourth
    */
   public character getScheduleFourth()
   {
      return (new character(scheduleFourth));
   }

   /**
    * Setter: scheduleFourth
    * 
    * @param   scheduleFourth
    *          scheduleFourth
    */
   public void setScheduleFourth(Text scheduleFourth)
   {
      this.scheduleFourth.assign(scheduleFourth, true);
   }

   /**
    * Getter: scheduleFifth
    * 
    * @return  scheduleFifth
    */
   public character getScheduleFifth()
   {
      return (new character(scheduleFifth));
   }

   /**
    * Setter: scheduleFifth
    * 
    * @param   scheduleFifth
    *          scheduleFifth
    */
   public void setScheduleFifth(Text scheduleFifth)
   {
      this.scheduleFifth.assign(scheduleFifth, true);
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  schedule
    */
   public Text getSchedule(int index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   schedule
    *          schedule
    */
   public void setSchedule(int index, Text schedule)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  schedule
    */
   public Text getSchedule(NumberType index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   schedule
    *          schedule
    */
   public void setSchedule(NumberType index, Text schedule)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Report number of list elements for schedule
    * 
    * @return  Number of list elements for schedule
    */
   public integer sizeSchedule()
   {
      return (new integer(5));
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours1()
   {
      return (new integer(hours1));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours1
    *          Hours
    */
   public void setHours1(NumberType hours1)
   {
      this.hours1.assign(hours1, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours2()
   {
      return (new integer(hours2));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours2
    *          Hours
    */
   public void setHours2(NumberType hours2)
   {
      this.hours2.assign(hours2, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours3()
   {
      return (new integer(hours3));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours3
    *          Hours
    */
   public void setHours3(NumberType hours3)
   {
      this.hours3.assign(hours3, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours4()
   {
      return (new integer(hours4));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours4
    *          Hours
    */
   public void setHours4(NumberType hours4)
   {
      this.hours4.assign(hours4, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours5()
   {
      return (new integer(hours5));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours5
    *          Hours
    */
   public void setHours5(NumberType hours5)
   {
      this.hours5.assign(hours5, true);
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  hours
    */
   public NumberType getHours(int index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   hours
    *          hours
    */
   public void setHours(int index, NumberType hours)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  hours
    */
   public NumberType getHours(NumberType index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   hours
    *          hours
    */
   public void setHours(NumberType index, NumberType hours)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Report number of list elements for hours
    * 
    * @return  Number of list elements for hours
    */
   public integer sizeHours()
   {
      return (new integer(5));
   }
}
